# $File: //member/autrijus/Module-Install-RTx/t/1-basic.t $ $Author: autrijus $
# $Revision: #1 $ $Change: 9316 $ $DateTime: 2003/12/15 05:03:39 $

print "1..1\n";

require Module::Install::RTx;

print "ok 1\n";

1;
